function [u] = Burgers1DEx4(u,epsilon,xL,xR,FinalTime)

% function [u] = Burgers1D(u,nu,xL,xR,FinalTime)
% Purpose  : Integrate 1D Burgers equation until 
%            FinalTime starting with
%            initial condition u in the domain [xL,xR].
%            sqrt(epsilon) is the coefficient of viscosity

Globals1D;
time = 0;

% Runge-Kutta residual storage  
resu = zeros(Np,K); 

% Initialize filter
F = Filter1D(N,0,8);

% Initialize interpolation
r2 = JacobiGL(0,0,2*N);
V2  = Vandermonde1D(2*N, r2); invV2 = inv(V2);

% compute time step size
xmin = min(abs(x(1,:)-x(2,:)));
CFL=0.25; umax = max(max(abs(u)));
dt = CFL* min(xmin/umax);
Nsteps = ceil(FinalTime/dt); 
dt = FinalTime/Nsteps; 

% outer time step loop 
for tstep=1:Nsteps

    for INTRK = 1:5
        timelocal = time + rk4c(INTRK)*dt;
        [rhsu] = BurgersRHS1DEx4(u,epsilon,xL,xR,timelocal,V2,invV2);
        resu = rk4a(INTRK)*resu + dt*rhsu;
        u = u+rk4b(INTRK)*resu;
    end;
    % Filter
    % u = F*u;
    
    % Limit solution
    % u = SlopeLimitN(u);
    
    % Increment time
    time = time+dt;
    ue = 1./(cosh(epsilon*(x+5.0)-time).^2) + 1.0;
    plot(x(:),u(:),x(:), ue(:));
drawnow;
end;




return
