function [rhsu] = BurgersRHS1DEx4(u,epsilon,xL,xR,time,V2,invV2)

% function [rhsu] = BurgersRHS1DEx4(u,epsilon,xL, xR, time,V2,invV2)
% Purpose  : Evaluate RHS flux in 1D viscous Burgers equation

Globals1D;

% Define field differences at faces
du = zeros(Nfp*Nfaces,K); du(:) = u(vmapM)-u(vmapP);

% impose boundary condition at x=0
uin = 1./(cosh(epsilon*(xL+5.0)-time).^2) + 1.0;
du(mapI) = 2.0*(u(vmapI)-uin);
du(mapO) = 0;

% Evaluate nonlinear flux
% Approximately
u2 = u.*u;

% Exactly
%uhat = invV*u;
%uhat2N = zeros(2*N+1,K);
%uhat2N(1:Np,:) = uhat;
%u2N = V2*uhat2N;
%u2N2 = u2N.*u2N;
%u2N2hat = invV2*u2N2;
%uhat = u2N2hat(1:Np,:);
%u2 = V*uhat;

du2 = zeros(Nfp*Nfaces,K); 
du2(:) = (u2(vmapM)-u2(vmapP))/2.0;

% impose boundary condition
du2(mapI)=(u2(vmapI)-uin.^2); 
du2(mapO)=0;

% Compute flux
%maxvel = max(max(abs(u)));
maxvel = 0;

% flux term
flux = nx.*(du2/2.0) - maxvel/2.0.*du;

% local derivatives of field
dfdr = Dr*(u2/2); 

% compute right hand sides of the semi-discrete PDE
al    = epsilon*(x+5.0) - time;
force = 2*sinh(al)./(cosh(al).^3).*(1 - epsilon*(1./(cosh(al).^2) + 1.0));
rhsu = -(rx.*dfdr - LIFT*(Fscale.*flux)) + force;

return
